@@ -1,12 +1,9 @@
 import sys
 from bisect import bisect_left
 from typing import (
-    Dict,
     Generic,
-    List,
     NamedTuple,
     Optional,
-    Type,
     TypeVar,
     cast,
     overload,
@@ -17,9 +14,9 @@ from qrcode import constants, exceptions, util
 from qrcode.image.base import BaseImage
 from qrcode.image.pure import PyPNGImage
 
-ModulesType = List[List[Optional[bool]]]
+ModulesType = list[list[Optional[bool]]]
 # Cache modules generated just based on the QR Code version
-precomputed_qr_blanks: Dict[int, ModulesType] = {}
+precomputed_qr_blanks: dict[int, ModulesType] = {}
 
 
 def make(data=None, **kwargs):
@@ -84,7 +81,7 @@ class QRCode(Generic[GenericImage]):
         error_correction=constants.ERROR_CORRECT_M,
         box_size=10,
         border=4,
-        image_factory: Optional[Type[GenericImage]] = None,
+        image_factory: Optional[type[GenericImage]] = None,
         mask_pattern=None,
     ):
         _check_box_size(box_size)
@@ -336,7 +333,7 @@ class QRCode(Generic[GenericImage]):
 
     @overload
     def make_image(
-        self, image_factory: Type[GenericImageLocal] = None, **kwargs
+        self, image_factory: type[GenericImageLocal] = None, **kwargs
     ) -> GenericImageLocal: ...
 
     def make_image(self, image_factory=None, **kwargs):
@@ -345,8 +342,12 @@ class QRCode(Generic[GenericImage]):
 
         If the data has not been compiled yet, make it first.
         """
+        # allow embeded_ parameters with typos for backwards compatibility
         if (
-            kwargs.get("embeded_image_path") or kwargs.get("embeded_image")
+            kwargs.get("embedded_image_path")
+            or kwargs.get("embedded_image")
+            or kwargs.get("embeded_image_path")
+            or kwargs.get("embeded_image")
         ) and self.error_correction != constants.ERROR_CORRECT_H:
             raise ValueError(
                 "Error correction level must be ERROR_CORRECT_H if an embedded image is provided"
@@ -527,13 +528,13 @@ class QRCode(Generic[GenericImage]):
         code = [[False] * width] * self.border
         x_border = [False] * self.border
         for module in self.modules:
-            code.append(x_border + cast(List[bool], module) + x_border)
+            code.append(x_border + cast(list[bool], module) + x_border)
         code += [[False] * width] * self.border
 
         return code
 
     def active_with_neighbors(self, row: int, col: int) -> ActiveWithNeighbors:
-        context: List[bool] = []
+        context: list[bool] = []
         for r in range(row - 1, row + 2):
             for c in range(col - 1, col + 2):
                 context.append(self.is_constrained(r, c) and bool(self.modules[r][c]))
